
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.20.4rc3',
    'branch_nick': 'patch-0-Release__1_20_4rc3_prep',
    'revision_id': 'fe0518d675a40da8d34fae3c505a3763cc669c12',
    'revno': 8433
}
